@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import List, Union
+from typing import Any, Dict, List, Type, Union
 from xml.etree.ElementTree import ParseError, fromstring, tostring
 
 import pandas as pd
@@ -94,6 +94,21 @@ class HttpAPIDataSource(ToucanDataSource):
     filter: str = FilterSchema
     flatten_column: str = Field(None, description='Column containing nested rows')
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any], model: Type['HttpAPIDataSource']) -> None:
+            keys = schema['properties'].keys()
+            last_keys = [
+                'proxies',
+                'flatten_column',
+                'data',
+                'xpath',
+                'filter',
+                'validation',
+            ]
+            new_keys = [k for k in keys if k not in last_keys] + last_keys
+            schema['properties'] = {k: schema['properties'][k] for k in new_keys}
+
 
 class HttpAPIConnector(ToucanConnector):
     data_source_model: HttpAPIDataSource
@@ -107,6 +122,9 @@ class HttpAPIConnector(ToucanConnector):
         None,
         description='You can provide a custom template that will be used for every HTTP request',
     )
+    _sso_credentials_access: bool = True
+
+    sso_credentials_keeper: Any = None
 
     def do_request(self, query, session):
         """
