@@ -60,7 +60,8 @@ class HubspotDataSource(ToucanDataSource):
 class HubspotConnector(ToucanConnector):
     _auth_flow = 'oauth2'
     auth_flow_id: Optional[str]
-
+    _oauth_trigger = 'instance'
+    oauth2_version = Field('1', **{'ui.hidden': True})
     data_source_model: HubspotDataSource
 
     def __init__(self, **kwargs) -> None:
